@@ -13,15 +13,21 @@ from .client import (
     RunUpdate,
     RunResponse,
     RunStatus,
+    FileInput,
     ConnectionCreate,
     ConnectionResponse,
     ConnectionStatus,
     TrajectoryCreate,
     TrajectoryUpdate,
     TrajectoryResponse,
+    RunAttachmentCreate,
+    RunAttachmentUpdate,
+    RunAttachmentResponse,
+    RunAttachmentDownloadUrlResponse,
+    AttachmentType,
 )
 
-__version__ = "1.8.0"
+__version__ = "2.1.17"
 
 __all__ = [
     "CyberdeskClient",
@@ -36,10 +42,16 @@ __all__ = [
     "RunUpdate",
     "RunResponse",
     "RunStatus",
+    "FileInput",
     "ConnectionCreate",
     "ConnectionResponse",
     "ConnectionStatus",
     "TrajectoryCreate",
     "TrajectoryUpdate",
     "TrajectoryResponse",
+    "RunAttachmentCreate",
+    "RunAttachmentUpdate",
+    "RunAttachmentResponse",
+    "RunAttachmentDownloadUrlResponse",
+    "AttachmentType",
 ] 
\ No newline at end of file
